@@ -68,6 +68,10 @@ namespace Nereid
         private CompositeTrackSourceContents composite_view;
         private ObjectListSourceContents object_view;
         private Label status_label;
+
+        protected PlayerInterface (IntPtr ptr) : base (ptr)
+        {
+        }
         
         public PlayerInterface () : base (Catalog.GetString ("Banshee Media Player"), "player_window", 1024, 700)
         {
@@ -329,9 +333,10 @@ namespace Nereid
             }
             
             // Connect the source models to the views if possible
-            ISourceContents contents = source.GetInheritedProperty<bool> ("Nereid.SourceContentsPropagate")
-                ? source.GetInheritedProperty<ISourceContents> ("Nereid.SourceContents")
-                : source.Properties.Get<ISourceContents> ("Nereid.SourceContents");
+            ISourceContents contents = source.GetProperty<ISourceContents> ("Nereid.SourceContents",
+                source.GetInheritedProperty<bool> ("Nereid.SourceContentsPropagate"));
+
+            view_container.ClearFooter ();
             
             if (contents != null) {
                 if (view_container.Content != contents) {
@@ -363,10 +368,8 @@ namespace Nereid
 
             view_container.Header.Visible = source.Properties.Contains ("Nereid.SourceContents.HeaderVisible") ?
                 source.Properties.Get<bool> ("Nereid.SourceContents.HeaderVisible") : true;
-            
-            view_container.ClearFooter ();
+
             Widget footer_widget = null;
-            
             if (source.Properties.Contains ("Nereid.SourceContents.FooterWidget")) {
                 footer_widget = source.Properties.Get<Widget> ("Nereid.SourceContents.FooterWidget");
             }
@@ -470,6 +473,9 @@ namespace Nereid
                 case Gdk.Key.F3: case Gdk.Key.slash:
                     focus_search = true;
                     break;
+                case Gdk.Key.F11:
+                    ActionService.ViewActions["FullScreenAction"].Activate ();
+                    break;
             }
 
             if (focus_search && !view_container.SearchEntry.HasFocus && !source_view.EditingRow) {
