@@ -52,8 +52,8 @@ namespace Banshee.Database
         // NOTE: Whenever there is a change in ANY of the database schema,
         //       this version MUST be incremented and a migration method
         //       MUST be supplied to match the new version number
-        protected const int CURRENT_VERSION = 17;
-        protected const int CURRENT_METADATA_VERSION = 2;
+        protected const int CURRENT_VERSION = 22;
+        protected const int CURRENT_METADATA_VERSION = 4;
         
 #region Migration Driver
         
@@ -219,7 +219,7 @@ namespace Banshee.Database
         private bool Migrate_1 ()
         {
             if (TableExists("Tracks")) {
-                InitializeFreshDatabase ();
+                InitializeFreshDatabase (true);
                 
                 uint timer_id = Log.DebugTimerStart ("Database Schema Migration");
 
@@ -240,7 +240,7 @@ namespace Banshee.Database
                 
                 return false;
             } else {
-                InitializeFreshDatabase ();
+                InitializeFreshDatabase (false);
                 return false;
             }
         }
@@ -482,11 +482,79 @@ namespace Banshee.Database
         
 #endregion
 
+#region Version 18
+
+        [DatabaseVersion (18)]
+        private bool Migrate_18 ()
+        {
+            Execute ("ALTER TABLE CoreTracks ADD COLUMN MetadataHash TEXT");
+            return true;
+        }
+        
+#endregion
+        
+#region Version 19
+
+        [DatabaseVersion (19)]
+        private bool Migrate_19 ()
+        {
+            Execute ("ALTER TABLE CoreAlbums ADD COLUMN IsCompilation INTEGER DEFAULT 0");
+            Execute ("ALTER TABLE CoreTracks ADD COLUMN BPM INTEGER");
+            Execute ("ALTER TABLE CoreTracks ADD COLUMN DiscCount INTEGER");
+            Execute ("ALTER TABLE CoreTracks ADD COLUMN Conductor TEXT");
+            Execute ("ALTER TABLE CoreTracks ADD COLUMN Grouping TEXT");
+            Execute ("ALTER TABLE CoreTracks ADD COLUMN BitRate INTEGER DEFAULT 0");
+            return true;
+        }
+        
+#endregion
+
+#region Version 20
+
+        [DatabaseVersion (20)]
+        private bool Migrate_20 ()
+        {
+            Execute ("ALTER TABLE CoreSmartPlaylists ADD COLUMN IsTemporary INTEGER DEFAULT 0");
+            Execute ("ALTER TABLE CorePlaylists ADD COLUMN IsTemporary INTEGER DEFAULT 0");
+            Execute ("ALTER TABLE CorePrimarySources ADD COLUMN IsTemporary INTEGER DEFAULT 0");
+            return true;
+        }
+        
+#endregion
+
+#region Version 21
+
+        [DatabaseVersion (21)]
+        private bool Migrate_21 ()
+        {
+            // We had a bug where downloaded podcast episodes would no longer have the Podcast attribute.
+            int id = connection.Query<int> ("SELECT PrimarySourceId FROM CorePrimarySources WHERE StringID = 'PodcastSource-PodcastLibrary'");
+            if (id > 0) {
+                connection.Execute ("UPDATE CoreTracks SET Attributes = Attributes | ? WHERE PrimarySourceID = ?", (int)TrackMediaAttributes.Podcast, id);
+            }
+            return true;
+        }
+        
+#endregion
+
+#region Version 22
+
+        [DatabaseVersion (22)]
+        private bool Migrate_22 ()
+        {
+            Execute ("ALTER TABLE CoreTracks ADD COLUMN LastSyncedStamp INTEGER DEFAULT NULL");
+            Execute ("ALTER TABLE CoreTracks ADD COLUMN FileModifiedStamp INTEGER DEFAULT NULL");
+            Execute ("UPDATE CoreTracks SET LastSyncedStamp = DateAddedStamp;");
+            return true;
+        }
+        
+#endregion
+
 #pragma warning restore 0169
         
 #region Fresh database setup
         
-        private void InitializeFreshDatabase ()
+        private void InitializeFreshDatabase (bool refresh_metadata)
         {
             Execute("DROP TABLE IF EXISTS CoreConfiguration");
             Execute("DROP TABLE IF EXISTS CoreTracks");
@@ -508,13 +576,16 @@ namespace Banshee.Database
                 )
             ");
             Execute (String.Format ("INSERT INTO CoreConfiguration VALUES (null, 'DatabaseVersion', {0})", CURRENT_VERSION));
-            Execute ("INSERT INTO CoreConfiguration VALUES (null, 'MetadataVersion', 0)");
+            if (!refresh_metadata) {
+                Execute (String.Format ("INSERT INTO CoreConfiguration VALUES (null, 'MetadataVersion', {0})", CURRENT_METADATA_VERSION));
+            }
             
             Execute(@"
                 CREATE TABLE CorePrimarySources (
                     PrimarySourceID     INTEGER PRIMARY KEY,
                     StringID            TEXT UNIQUE,
-                    CachedCount         INTEGER
+                    CachedCount         INTEGER,
+                    IsTemporary         INTEGER DEFAULT 0
                 )
             ");
             Execute ("INSERT INTO CorePrimarySources (StringID) VALUES ('MusicLibrarySource-Library')");
@@ -537,6 +608,7 @@ namespace Banshee.Database
                     UriType             INTEGER,
                     MimeType            TEXT,
                     FileSize            INTEGER,
+                    BitRate             INTEGER,
                     Attributes          INTEGER DEFAULT {0},
                     LastStreamError     INTEGER DEFAULT {1},
                     
@@ -545,10 +617,13 @@ namespace Banshee.Database
                     TrackNumber         INTEGER,
                     TrackCount          INTEGER,
                     Disc                INTEGER,
+                    DiscCount           INTEGER,
                     Duration            INTEGER,
                     Year                INTEGER,
                     Genre               TEXT,
                     Composer            TEXT,
+                    Conductor           TEXT,
+                    Grouping            TEXT,
                     Copyright           TEXT,
                     LicenseUri          TEXT,
 
@@ -559,7 +634,11 @@ namespace Banshee.Database
                     LastPlayedStamp     INTEGER,
                     LastSkippedStamp    INTEGER,
                     DateAddedStamp      INTEGER,
-                    DateUpdatedStamp    INTEGER
+                    DateUpdatedStamp    INTEGER,
+                    MetadataHash        TEXT,
+                    BPM                 INTEGER,
+                    LastSyncedStamp     INTEGER,
+                    FileModifiedStamp   INTEGER
                 )
             ", (int)TrackMediaAttributes.Default, (int)StreamPlaybackError.None));
             Execute("CREATE INDEX CoreTracksPrimarySourceIndex ON CoreTracks(ArtistID, AlbumID, PrimarySourceID, Disc, TrackNumber, Uri)");
@@ -582,6 +661,7 @@ namespace Banshee.Database
                     ReleaseDate         INTEGER,
                     Duration            INTEGER,
                     Year                INTEGER,
+                    IsCompilation       INTEGER DEFAULT 0,
                     
                     ArtistName          TEXT,
                     ArtistNameLowered   TEXT,
@@ -612,7 +692,8 @@ namespace Banshee.Database
                     SortColumn          INTEGER NOT NULL DEFAULT -1,
                     SortType            INTEGER NOT NULL DEFAULT 0,
                     Special             INTEGER NOT NULL DEFAULT 0,
-                    CachedCount         INTEGER
+                    CachedCount         INTEGER,
+                    IsTemporary         INTEGER DEFAULT 0
                 )
             ");
             
@@ -635,7 +716,8 @@ namespace Banshee.Database
                     OrderBy             TEXT,
                     LimitNumber         TEXT,
                     LimitCriterion      TEXT,
-                    CachedCount         INTEGER
+                    CachedCount         INTEGER,
+                    IsTemporary         INTEGER DEFAULT 0
                 )
             ");
                 
@@ -688,7 +770,7 @@ namespace Banshee.Database
                             FROM CoreArtists 
                             WHERE Name = Tracks.Artist
                             LIMIT 1),
-                        0, null, AlbumTitle, NULL, ReleaseDate, 0, 0, Artist, NULL, 0
+                        0, null, AlbumTitle, NULL, ReleaseDate, 0, 0, 0, Artist, NULL, 0
                         FROM Tracks
                         ORDER BY AlbumTitle
             ");
@@ -712,24 +794,25 @@ namespace Banshee.Database
                         Uri,
                         0,
                         MimeType,
-                        0,
+                        0, 0,
                         {0},
                         {1},
                         Title, NULL,
                         TrackNumber,
                         TrackCount,
-                        0,
+                        0, 0,
                         Duration * 1000,
                         Year,
                         Genre,
-                        NULL, NULL, NULL, NULL,
+                        NULL, NULL, NULL, NULL, NULL, NULL,
                         Rating,
                         NumberOfPlays,
                         0,
                         LastPlayedStamp,
                         NULL,
                         DateAddedStamp,
-                        DateAddedStamp
+                        DateAddedStamp,
+                        NULL, NULL, DateAddedStamp, NULL
                         FROM Tracks
             ", (int)TrackMediaAttributes.Default, (int)StreamPlaybackError.None));
 
