@@ -62,7 +62,8 @@ namespace Banshee.Query
             RandomOrder,
             CreateQueryOrder ("Album",      asc,  Catalog.GetString ("Album"), AlbumField),
             CreateQueryOrder ("Artist",     asc,  Catalog.GetString ("Artist"), ArtistField),
-            CreateQueryOrder ("Title",      asc,  Catalog.GetString ("Title"), TitleField),
+            // Translators: noun
+            CreateQueryOrder ("Title",      asc,  Catalog.GetString ("Name"), TitleField),
             CreateQueryOrder ("Genre",      asc,  Catalog.GetString ("Genre"), GenreField),
             null,
             CreateQueryOrder ("Rating",     desc, Catalog.GetString ("Highest Rating"), RatingField),
@@ -91,38 +92,83 @@ namespace Banshee.Query
         public static QueryField ArtistField = new QueryField (
             "artist", "ArtistName",
             Catalog.GetString ("Artist"), "CoreArtists.NameLowered", true,
-            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            // Translators: These are unique search aliases for "artist".  Please, no spaces. Blank ok.
             Catalog.GetString ("artist"), Catalog.GetString ("by"), Catalog.GetString ("artists"),
             "by", "artist", "artists"
         );
 
+        public static QueryField AlbumArtistField = new QueryField (
+            "albumartist", "AlbumArtist",
+            Catalog.GetString ("Album Artist"), "CoreAlbums.ArtistNameLowered", true,
+            // Translators: These are unique search aliases for "album".  Please, no spaces. Blank ok.
+            Catalog.GetString ("albumartist"), Catalog.GetString ("compilationartist"),
+            "albumartist", "compilationartist"
+        );
+
+        // TODO add IsCompilationField
+
         public static QueryField AlbumField = new QueryField (
             "album", "AlbumTitle",
             Catalog.GetString ("Album"), "CoreAlbums.TitleLowered", true,
-            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            // Translators: These are unique search aliases for "album".  Please, no spaces. Blank ok.
             Catalog.GetString ("album"), Catalog.GetString ("on"), Catalog.GetString ("from"),
             "on", "album", "from", "albumtitle"
         );
 
-        public static QueryField DiscField = new QueryField (
-            "disc", "Disc",
+        public static QueryField DiscNumberField = new QueryField (
+            "disc", "DiscNumber",
             Catalog.GetString ("Disc"), "CoreTracks.Disc", typeof(NaturalIntegerQueryValue),
-            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            // Translators: These are unique search fields (and nouns).  Please, no spaces. Blank ok.
             Catalog.GetString ("disc"), Catalog.GetString ("cd"), Catalog.GetString ("discnum"),
             "disc", "cd", "discnum"
         );
+
+        public static QueryField DiscCountField = new QueryField (
+            "disccount", "DiscCount",
+            Catalog.GetString ("Disc Count"), "CoreTracks.DiscCount", typeof(NaturalIntegerQueryValue),
+            // Translators: These are unique search fields (and nouns).  Please, no spaces. Blank ok.
+            Catalog.GetString ("discs"), Catalog.GetString ("cds"),
+            "discs", "cds"
+        );
         
         public static QueryField TrackNumberField = new QueryField (
             "track", "TrackNumber",
-            Catalog.GetString ("Track"), "CoreTracks.TrackNumber", typeof(NaturalIntegerQueryValue),
+            // Translators: noun
+            Catalog.GetString ("Track Number"), "CoreTracks.TrackNumber", typeof(NaturalIntegerQueryValue),
             // Translators: These are unique search fields.  Please, no spaces. Blank ok.
             "#", Catalog.GetString ("track"), Catalog.GetString ("trackno"), Catalog.GetString ("tracknum"),
             "track", "trackno", "tracknum"
         );
 
+        public static QueryField TrackCountField = new QueryField (
+            "trackcount", "TrackCount",
+            // Translators: noun
+            Catalog.GetString ("Track Count"), "CoreTracks.TrackCount", typeof(NaturalIntegerQueryValue),
+            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            Catalog.GetString ("tracks"), Catalog.GetString ("trackcount"),
+            "tracks", "trackcount"
+        );
+
+        public static QueryField BpmField = new QueryField (
+            "bpm", "Bpm",
+            Catalog.GetString ("Beats per Minute"), "CoreTracks.BPM", typeof(NaturalIntegerQueryValue),
+            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            Catalog.GetString ("bpm"),
+            "bpm"
+        );
+
+        public static QueryField BitRateField = new QueryField (
+            "bitrate", "BitRate",
+            // Translators: noun
+            Catalog.GetString ("Bit Rate"), "CoreTracks.BitRate", typeof(NaturalIntegerQueryValue),
+            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            Catalog.GetString ("bitrate"), Catalog.GetString ("kbs"), Catalog.GetString ("kps"),
+            "bitrate", "kbs", "kps"
+        );
+
         public static QueryField TitleField = new QueryField (
             "title", "TrackTitle",
-            Catalog.GetString ("Title"), "CoreTracks.TitleLowered", true,
+            Catalog.GetString ("Name"), "CoreTracks.TitleLowered", true,
             // Translators: These are unique search fields.  Please, no spaces. Blank ok.
             Catalog.GetString ("title"), Catalog.GetString ("titled"), Catalog.GetString ("name"), Catalog.GetString ("named"),
             "title", "titled", "name", "named"
@@ -150,10 +196,25 @@ namespace Banshee.Query
             Catalog.GetString ("composer"), "composer"
         );
 
+        public static QueryField ConductorField = new QueryField (
+            "conductor", "Conductor",
+            Catalog.GetString ("Conductor"), "CoreTracks.Conductor", false,
+            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            Catalog.GetString ("conductor"), "conductor"
+        );
+
+        public static QueryField GroupingField = new QueryField (
+            "grouping", "Grouping",
+            Catalog.GetString ("Grouping"), "CoreTracks.Grouping", false,
+            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            Catalog.GetString ("grouping"), "grouping"
+        );
+
         public static QueryField CommentField = new QueryField (
             "comment", "Comment",
+            // Translators: noun
             Catalog.GetString ("Comment"), "CoreTracks.Comment", false,
-            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            // Translators: These are unique search fields (and nouns).  Please, no spaces. Blank ok.
             Catalog.GetString ("comment"), "comment"
         );
 
@@ -168,7 +229,7 @@ namespace Banshee.Query
         public static QueryField PlayCountField = new QueryField (
             "playcount", "PlayCount",
             Catalog.GetString ("Play Count"), "CoreTracks.PlayCount", typeof(NaturalIntegerQueryValue),
-            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            // Translators: These are unique search fields (and nouns).  Please, no spaces. Blank ok.
             Catalog.GetString ("plays"), Catalog.GetString ("playcount"), Catalog.GetString ("listens"),
             "plays", "playcount", "numberofplays", "listens"
         );
@@ -176,7 +237,7 @@ namespace Banshee.Query
         public static QueryField SkipCountField = new QueryField (
             "skipcount", "SkipCount",
             Catalog.GetString ("Skip Count"), "CoreTracks.SkipCount", typeof(NaturalIntegerQueryValue),
-            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            // Translators: These are unique search fields (and nouns).  Please, no spaces. Blank ok.
             Catalog.GetString ("skips"), Catalog.GetString ("skipcount"),
             "skips", "skipcount"
         );
@@ -184,7 +245,7 @@ namespace Banshee.Query
         public static QueryField FileSizeField = new QueryField (
             "filesize", "FileSize",
             Catalog.GetString ("File Size"), "CoreTracks.FileSize", typeof(FileSizeQueryValue),
-            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            // Translators: These are unique search fields (and nouns).  Please, no spaces. Blank ok.
             Catalog.GetString ("size"), Catalog.GetString ("filesize"),
             "size", "filesize"
         );
@@ -199,7 +260,7 @@ namespace Banshee.Query
 
         public static QueryField DurationField = new QueryField (
             "duration", "Duration",
-            Catalog.GetString ("Duration"), "CoreTracks.Duration", typeof(TimeSpanQueryValue),
+            Catalog.GetString ("Time"), "CoreTracks.Duration", typeof(TimeSpanQueryValue),
             // Translators: These are unique search fields.  Please, no spaces. Blank ok.
             Catalog.GetString ("duration"), Catalog.GetString ("length"), Catalog.GetString ("time"),
             "duration", "length", "time"
@@ -215,7 +276,7 @@ namespace Banshee.Query
 
         public static QueryField LastPlayedField = new QueryField (
             "lastplayed", "LastPlayed",
-            Catalog.GetString ("Last Played Date"), "CoreTracks.LastPlayedStamp", new Type [] {typeof(RelativeTimeSpanQueryValue), typeof(DateQueryValue)},
+            Catalog.GetString ("Last Played"), "CoreTracks.LastPlayedStamp", new Type [] {typeof(RelativeTimeSpanQueryValue), typeof(DateQueryValue)},
             // Translators: These are unique search fields.  Please, no spaces. Blank ok.
             Catalog.GetString ("lastplayed"), Catalog.GetString ("played"), Catalog.GetString ("playedon"),
             "lastplayed", "played", "playedon"
@@ -223,7 +284,7 @@ namespace Banshee.Query
 
         public static QueryField LastSkippedField = new QueryField (
             "lastskipped", "LastSkipped",
-            Catalog.GetString ("Last Skipped Date"), "CoreTracks.LastSkippedStamp", new Type [] {typeof(RelativeTimeSpanQueryValue), typeof(DateQueryValue)},
+            Catalog.GetString ("Last Skipped"), "CoreTracks.LastSkippedStamp", new Type [] {typeof(RelativeTimeSpanQueryValue), typeof(DateQueryValue)},
             // Translators: These are unique search fields.  Please, no spaces. Blank ok.
             Catalog.GetString ("lastskipped"), Catalog.GetString ("skipped"), Catalog.GetString ("skippedon"),
             "lastskipped", "skipped", "skippedon"
@@ -252,11 +313,21 @@ namespace Banshee.Query
 #endregion
 
         public static QueryFieldSet FieldSet = new QueryFieldSet (
-            ArtistField, AlbumField, DiscField, TitleField, YearField, GenreField, ComposerField, CommentField, RatingField, PlayCountField,
+            ArtistField, AlbumField, AlbumArtistField, TitleField, TrackNumberField, TrackCountField, DiscNumberField, DiscCountField,
+            YearField, GenreField, ComposerField, ConductorField, GroupingField, CommentField, RatingField, PlayCountField,
             SkipCountField, FileSizeField, UriField, DurationField, MimeTypeField, LastPlayedField, LastSkippedField,
-            DateAddedField, PlaylistField, SmartPlaylistField
+            BpmField, BitRateField, DateAddedField, PlaylistField, SmartPlaylistField
         );
 
+        // Type Initializer
+        static BansheeQuery ()
+        {
+            // Translators: noun
+            BpmField.ShortLabel         = Catalog.GetString ("BPM");
+            SkipCountField.ShortLabel   = Catalog.GetString ("Skips");
+            PlayCountField.ShortLabel   = Catalog.GetString ("Plays");
+        }
+
         private const string default_sort = @"CoreAlbums.ArtistNameLowered ASC, CoreAlbums.TitleLowered ASC, CoreTracks.Disc ASC, CoreTracks.TrackNumber ASC";
         public static string GetSort (string key)
         {
@@ -271,6 +342,7 @@ namespace Banshee.Query
             string column = null;
             switch (key.ToLower ()) {
                 case "track":
+                case "grouping":
                     sort_query = String.Format (@"
                         CoreAlbums.ArtistNameLowered ASC, 
                         CoreAlbums.TitleLowered ASC, 
@@ -278,6 +350,14 @@ namespace Banshee.Query
                         CoreTracks.TrackNumber {0}", ascDesc); 
                     break;
 
+                case "albumartist":
+                    sort_query = String.Format (@"
+                        CoreAlbums.ArtistNameLowered {0}, 
+                        CoreAlbums.TitleLowered ASC, 
+                        CoreTracks.Disc ASC,
+                        CoreTracks.TrackNumber ASC", ascDesc); 
+                    break;
+
                 case "artist":
                     sort_query = String.Format (@"
                         CoreArtists.NameLowered {0}, 
@@ -304,6 +384,14 @@ namespace Banshee.Query
                     sort_query = "RANDOM ()";
                     break;
 
+                case "disc":
+                    sort_query = String.Format (@"
+                        CoreAlbums.ArtistNameLowered ASC, 
+                        CoreAlbums.TitleLowered ASC, 
+                        CoreTracks.Disc {0},
+                        CoreTracks.TrackNumber ASC", ascDesc);
+                    break;
+
                 // FIXME hacks to aid in migration of these sort keys to actually
                 // using the QueryField (or at least their .Names)
                 case "lastplayed":
@@ -315,8 +403,12 @@ namespace Banshee.Query
                     goto case "comment";
 
                 case "year":
+                case "bitrate":
+                case "bpm":
+                case "conductor":
+                case "trackcount":
+                case "disccount":
                 case "genre":
-                case "disc":
                 case "duration":
                 case "rating":
                 case "playcount":
