@@ -84,6 +84,15 @@ namespace Banshee.Dap.Ipod
             name_path = Path.Combine (Path.GetDirectoryName (ipod_device.TrackDatabasePath), "BansheeIPodName");
             Name = GetDeviceName ();
 
+            SupportsPlaylists = ipod_device.ModelInfo.DeviceClass != "shuffle";
+
+            // TODO disable this later, but right now it won't disable it in Sync, so might as well
+            // leave it enabled
+            //SupportsPodcasts = ipod_device.ModelInfo.HasCapability ("podcast");
+            SupportsVideo = ipod_device.ModelInfo.DeviceClass == "video" ||
+                            ipod_device.ModelInfo.DeviceClass == "classic" ||
+                            (ipod_device.ModelInfo.DeviceClass == "nano" && ipod_device.ModelInfo.Generation >= 3);
+
             Initialize ();
 
             AddDapProperty (Catalog.GetString ("Device"), ipod_device.ModelInfo.DeviceClass);
@@ -380,6 +389,22 @@ namespace Banshee.Dap.Ipod
 
 #region Syncing
 
+        protected override void OnTracksAdded ()
+        {
+            if (!IsAdding && tracks_to_add.Count > 0 && !Sync.Syncing) {
+                QueueSync ();
+            }
+            base.OnTracksAdded ();
+        }
+
+        protected override void OnTracksDeleted ()
+        {
+            if (!IsDeleting && tracks_to_remove.Count > 0 && !Sync.Syncing) {
+                QueueSync ();
+            }
+            base.OnTracksDeleted ();
+        }
+        
         private Queue<IpodTrackInfo> tracks_to_add = new Queue<IpodTrackInfo> ();
         private Queue<IpodTrackInfo> tracks_to_remove = new Queue<IpodTrackInfo> ();
         
@@ -389,9 +414,9 @@ namespace Banshee.Dap.Ipod
         private Thread sync_thread;
         private AutoResetEvent sync_thread_wait;
         private bool sync_thread_dispose = false;
-        
+
         public override bool IsReadOnly {
-            get { return ipod_device.IsReadOnly; }
+            get { return ipod_device.IsReadOnly || !database_supported; }
         }
         
         public override void Import ()
@@ -414,7 +439,6 @@ namespace Banshee.Dap.Ipod
                 IpodTrackInfo ipod_track = tracks_map[track.TrackId];
                 if (ipod_track != null) {
                     tracks_to_remove.Enqueue (ipod_track);
-                    QueueSync ();
                 }
             }
         }
@@ -432,14 +456,12 @@ namespace Banshee.Dap.Ipod
                 ipod_track.Save (false);
             
                 tracks_to_add.Enqueue (ipod_track);
-                
-                QueueSync ();
             }
         }
 
         public override void SyncPlaylists ()
         {
-            if (Monitor.TryEnter (sync_mutex)) {
+            if (!IsReadOnly && Monitor.TryEnter (sync_mutex)) {
                 PerformSync ();
                 Monitor.Exit (sync_mutex);
             }
@@ -452,7 +474,7 @@ namespace Banshee.Dap.Ipod
                     Application.IdleTimeoutRemove (sync_timeout_id);
                 }
                 
-                sync_timeout_id = Application.RunTimeout (1000, PerformSync);
+                sync_timeout_id = Application.RunTimeout (150, PerformSync);
             }
         }
         
@@ -561,21 +583,23 @@ namespace Banshee.Dap.Ipod
                 }
             }
             device_playlists.Clear ();
-
-            // Add playlists from Banshee to the device
-            foreach (Source child in Children) {
-                PlaylistSource from = child as PlaylistSource;
-                if (from != null && from.Count > 0) {
-                    IPod.Playlist playlist = ipod_device.TrackDatabase.CreatePlaylist (from.Name);
-                    foreach (int track_id in ServiceManager.DbConnection.QueryEnumerable<int> (String.Format (
-                        "SELECT CoreTracks.TrackID FROM CoreTracks{0} WHERE {1}",
-                        from.DatabaseTrackModel.JoinFragment, from.DatabaseTrackModel.Condition)))
-                    {
-                        playlist.AddTrack (tracks_map[track_id].IpodTrack);
+            
+            if (SupportsPlaylists) {
+                // Add playlists from Banshee to the device
+                foreach (Source child in Children) {
+                    PlaylistSource from = child as PlaylistSource;
+                    if (from != null && from.Count > 0) {
+                        IPod.Playlist playlist = ipod_device.TrackDatabase.CreatePlaylist (from.Name);
+                        foreach (int track_id in ServiceManager.DbConnection.QueryEnumerable<int> (String.Format (
+                            "SELECT CoreTracks.TrackID FROM CoreTracks{0} WHERE {1}",
+                            from.DatabaseTrackModel.JoinFragment, from.DatabaseTrackModel.Condition)))
+                        {
+                            playlist.AddTrack (tracks_map[track_id].IpodTrack);
+                        }
                     }
                 }
             }
-
+    
             // Sync podcast playlist
             /*IPod.Playlist podcast_playlist = GetPodcastPlaylist ();
             podcast_playlist.Clear ();
@@ -591,6 +615,8 @@ namespace Banshee.Dap.Ipod
                 ipod_device.TrackDatabase.SaveEnded += OnIpodDatabaseSaveEnded;
                 ipod_device.TrackDatabase.SaveProgressChanged += OnIpodDatabaseSaveProgressChanged;
                 ipod_device.Save ();
+            } catch (InsufficientSpaceException) {
+                ErrorSource.AddMessage (Catalog.GetString ("Out of space on device"), Catalog.GetString ("Please manually remove some songs"));
             } catch (Exception e) {
                 Log.Exception ("Failed to save iPod database", e);
             } finally {
