@@ -140,6 +140,18 @@ namespace Banshee.Dap
         {
         }
 
+        private bool supports_video = true;
+        public bool SupportsVideo {
+            get { return supports_video; }
+            protected set { supports_video = value; }
+        }
+
+        private bool supports_podcasts = true;
+        public bool SupportsPodcasts {
+            get { return supports_podcasts; }
+            protected set { supports_podcasts = value; }
+        }
+
 #region Source
 
         protected override void Initialize ()
@@ -184,8 +196,14 @@ namespace Banshee.Dap
             }
             
             AddChildSource (music_group_source = new MusicGroupSource (this));
-            AddChildSource (video_group_source = new VideoGroupSource (this));
-            AddChildSource (podcast_group_source = new PodcastGroupSource (this));
+
+            if (SupportsVideo) {
+                AddChildSource (video_group_source = new VideoGroupSource (this));
+            }
+
+            if (SupportsPodcasts) {
+                AddChildSource (podcast_group_source = new PodcastGroupSource (this));
+            }
 
             BuildPreferences ();
 
@@ -300,7 +318,7 @@ namespace Banshee.Dap
         private void AttemptToAddTrackToDevice (DatabaseTrackInfo track, SafeUri fromUri)
         {
             // Ensure there's enough space
-            if (BytesAvailable - Banshee.IO.File.GetSize (fromUri) >= 0) {
+            if (Banshee.IO.File.Exists (fromUri) && BytesAvailable - Banshee.IO.File.GetSize (fromUri) >= 0) {
                 // Ensure it's not already on the device
                 if (ServiceManager.DbConnection.Query<int> (track_on_dap_query, DbId, track.MetadataHash) == 0) {
                     AddTrackToDevice (track, fromUri);
@@ -366,7 +384,7 @@ namespace Banshee.Dap
                     "File format conversion support is not available"));
             }
             
-            transcoder.Enqueue (track, PreferredConfiguration, OnTrackTranscoded, OnTrackTranscodeCancelled);
+            transcoder.Enqueue (track, PreferredConfiguration, OnTrackTranscoded, OnTrackTranscodeCancelled, OnTrackTranscodeError);
         }
         
         private void OnTrackTranscoded (TrackInfo track, SafeUri outputUri)
@@ -386,6 +404,12 @@ namespace Banshee.Dap
         {
             IncrementAddedTracks (); 
         }
+
+        private void OnTrackTranscodeError (TrackInfo track)
+        {
+            ErrorSource.AddMessage (Catalog.GetString ("Error converting file"), track.Uri.ToString ());
+            IncrementAddedTracks ();
+        }
         
 #endregion
 
