@@ -50,7 +50,7 @@ namespace Banshee.CoverArt
     public class CoverArtService : IExtensionService
     {
         private InterfaceActionService action_service;
-		private ActionGroup actions;
+        private ActionGroup actions;
         private bool disposed;
         private uint ui_manager_id;
         
@@ -98,6 +98,7 @@ namespace Banshee.CoverArt
         
         private void Initialize ()
         {            
+            Banshee.Base.ThreadAssist.AssertInMainThread ();
             actions = new ActionGroup ("CoverArt");
             
             ActionEntry[] action_list = new ActionEntry [] {
@@ -123,22 +124,24 @@ namespace Banshee.CoverArt
             if (disposed) {
                 return;
             }
+
+            Banshee.Base.ThreadAssist.ProxyToMain (delegate {
+                Gtk.Action fetch_action = action_service.GlobalActions["FetchCoverArtAction"];
+                if (fetch_action != null) {
+                    action_service.GlobalActions.Remove (fetch_action);
+                }
+                
+                action_service.RemoveActionGroup ("CoverArt");
+                action_service.UIManager.RemoveUi (ui_manager_id);
+                
+                actions = null;
+                action_service = null;
+                
+                ServiceManager.SourceManager.MusicLibrary.TracksAdded -= OnTracksAdded;
+                ServiceManager.SourceManager.MusicLibrary.TracksChanged -= OnTracksChanged;
             
-            Gtk.Action fetch_action = action_service.GlobalActions["FetchCoverArtAction"];
-            if (fetch_action != null) {
-                action_service.GlobalActions.Remove (fetch_action);
-            }
-            
-            action_service.RemoveActionGroup ("CoverArt");
-            action_service.UIManager.RemoveUi (ui_manager_id);
-            
-            actions = null;
-            action_service = null;
-            
-            ServiceManager.SourceManager.MusicLibrary.TracksAdded -= OnTracksAdded;
-            ServiceManager.SourceManager.MusicLibrary.TracksChanged -= OnTracksChanged;
-            
-            disposed = true;
+                disposed = true;
+            });
         }
         
         public void FetchCoverArt ()
@@ -154,12 +157,18 @@ namespace Banshee.CoverArt
         
         public void FetchCoverArt (bool force)
         {
-            if (job == null && NetworkDetect.Instance.Connected) {
+            if (job == null && ServiceManager.Get<Network> ().Connected) {
                 DateTime last_scan = DateTime.MinValue;
                 
                 if (!force) {
-                    last_scan = DatabaseConfigurationClient.Client.Get<DateTime> ("last_cover_art_scan",
-                                                                                  DateTime.MinValue);
+                    try {
+                        last_scan = DatabaseConfigurationClient.Client.Get<DateTime> ("last_cover_art_scan",
+                                                                                      DateTime.MinValue);
+                    } catch (FormatException) {
+                        Log.Warning ("last_cover_art_scan is malformed, resetting to default value");
+                        DatabaseConfigurationClient.Client.Set<DateTime> ("last_cover_art_scan",
+                                                                          DateTime.MinValue);
+                    }
                 }
                 job = new CoverArtJob (last_scan);
                 job.Finished += delegate {
