@@ -53,14 +53,29 @@ namespace Hyena.Data.Gui
             get { return theme; }
         }
         
+        private bool changing_style = false;
+        
         protected override void OnStyleSet (Style old_style)
         {
+            if (changing_style) {
+                return;
+            }
+            
+            changing_style = true;
+            GtkUtilities.AdaptGtkRcStyle (this, typeof (TreeView));
+            changing_style = false;
+            
             base.OnStyleSet (old_style);
             RecomputeRowHeight = true;
             theme = new GtkTheme (this);
 
             // Save the drawable so we can reuse it
             Gdk.Drawable drawable = cell_context != null ? cell_context.Drawable : null;
+            
+            if (pango_layout != null) {
+                pango_layout.Dispose ();
+                pango_layout = null;
+            }
 
             cell_context = new CellContext ();
             cell_context.Theme = theme;
@@ -76,7 +91,10 @@ namespace Hyena.Data.Gui
             }
             
             cairo_context = CairoHelper.Create (evnt.Window);
-            CairoExtensions.CreateLayout (this, cairo_context, ref pango_layout);
+            if (pango_layout == null) {
+                pango_layout = CairoExtensions.CreateLayout (this, cairo_context);
+            }
+            
             cell_context.Context = cairo_context;
             cell_context.Layout = pango_layout;
             
@@ -116,6 +134,8 @@ namespace Hyena.Data.Gui
             cell_context.Sensitive = true;
             cell_context.TextAsForeground = true;
 
+            bool have_drawn_separator = false;
+
             for (int ci = 0; ci < column_cache.Length; ci++) {
                 if (pressed_column_is_dragging && pressed_column_index == ci) {
                     continue;
@@ -123,19 +143,19 @@ namespace Hyena.Data.Gui
                 
                 cell_area.X = column_cache[ci].X1 + Theme.TotalBorderWidth + header_rendering_alloc.X - HadjustmentValue;
                 cell_area.Width = column_cache[ci].Width;
-                PaintHeaderCell (cell_area, ci, false);
+                PaintHeaderCell (cell_area, ci, false, ref have_drawn_separator);
             }
             
             if (pressed_column_is_dragging && pressed_column_index >= 0) {
                 cell_area.X = pressed_column_x_drag + Allocation.X - HadjustmentValue;
                 cell_area.Width = column_cache[pressed_column_index].Width;
-                PaintHeaderCell (cell_area, pressed_column_index, true);
+                PaintHeaderCell (cell_area, pressed_column_index, true, ref have_drawn_separator);
             }
             
             cairo_context.ResetClip ();
         }
         
-        private void PaintHeaderCell (Rectangle area, int ci, bool dragging)
+        private void PaintHeaderCell (Rectangle area, int ci, bool dragging, ref bool have_drawn_separator)
         {
             if (ci < 0 || column_cache.Length <= ci)
                 return;
@@ -166,7 +186,9 @@ namespace Hyena.Data.Gui
                 cairo_context.Restore ();
             }
             
-            if (!dragging && ci < column_cache.Length - 1) {
+            if (!dragging && ci < column_cache.Length - 1 && (have_drawn_separator || 
+                column_cache[ci].MaxWidth != column_cache[ci].MinWidth)) {
+                have_drawn_separator = true;
                 Theme.DrawHeaderSeparator (cairo_context, area, area.Right);
             }
         }
@@ -279,7 +301,7 @@ namespace Hyena.Data.Gui
         
         private void PaintReorderLine (int row_index, Rectangle single_list_alloc)
         {
-            if (row_index == drag_reorder_row_index && Reorderable) {
+            if (row_index == drag_reorder_row_index && IsReorderable) {
                 cairo_context.Save ();
                 cairo_context.LineWidth = 1.0;
                 cairo_context.Antialias = Cairo.Antialias.None;
