@@ -62,6 +62,11 @@ namespace Hyena
         }
         
         public static string CamelCaseToUnderCase (string s)
+        {
+            return CamelCaseToUnderCase (s, '_');
+        }
+        
+        public static string CamelCaseToUnderCase (string s, char underscore)
         {
             if (String.IsNullOrEmpty (s)) {
                 return null;
@@ -75,9 +80,9 @@ namespace Hyena
                     continue;
                 }
 
-                undercase.Append (tokens[i].ToLower ());
+                undercase.Append (tokens[i].ToLower (System.Globalization.CultureInfo.InvariantCulture));
                 if (i < tokens.Length - 2) {
-                    undercase.Append ('_');
+                    undercase.Append (underscore);
                 }
             }
             
@@ -113,11 +118,36 @@ namespace Hyena
             return builder.ToString ();
         }
 
+        public static string RemoveNewlines (string input)
+        {
+            if (input != null) {
+                return input.Replace ("\r\n", String.Empty).Replace ("\n", String.Empty);
+            }
+            return null;
+        }
+
+        private static Regex tags = new Regex ("<[^>]+>", RegexOptions.Compiled | RegexOptions.Multiline);
+        public static string RemoveHtml (string input)
+        {
+            if (input == null) {
+                return input;
+            }
+
+            return tags.Replace (input, String.Empty);
+        }
+
         public static string DoubleToTenthsPrecision (double num)
+        {
+            return DoubleToTenthsPrecision (num, false);
+        }
+        
+        public static string DoubleToTenthsPrecision (double num, bool always_decimal)
         {
             num = Math.Round (num, 1, MidpointRounding.ToEven);
             return String.Format (
-                num == (int)num ? "{0:N0}" : "{0:N1}", num
+                !always_decimal && num == (int)num 
+                    ? "{0:N0}" : "{0:N1}",
+                num
             );
         }
         
